@@ -6,6 +6,8 @@ from subprocess import call
 from time import strftime
 from dotenv import load_dotenv
 from site24x7_plugin_helper.connector.database_client import DatabaseClient
+
+# setting up the argument parser
 parser = argparse.ArgumentParser(description='This is a helper script for Site24x7 plugins.')
 parser.add_argument('--plugin',
     help='Unique plugin name that will be shown in site24x7 plugin list',
@@ -19,7 +21,10 @@ parser.add_argument('--version',
     help="Which step of the plugin is this? (1, 2, 3, etc.)",
     required=False,
     type=int)
-parser.add_argument('--env', help='Path to .env file', default='.env')
+parser.add_argument('--server', help='IPv4', type=str)
+parser.add_argument('--database', help='Database name belongs to the server', type=str)
+parser.add_argument('--env', help='Path to .env file', default='.env', type=str)
+
 # load the environment variables from file location
 load_dotenv(dotenv_path=parser.parse_args().env)
 # DEBUG
@@ -39,12 +44,17 @@ def special_strftime():
 if __name__ == "__main__":
     this_plugin_name = parser.parse_args().plugin
     query = parser.parse_args().query
-    server = os.environ.get("SERVER")
-    database = os.environ.get("DATABASE")
+    server = parser.parse_args().server or os.environ.get("SERVER")
+    database = parser.parse_args().database or os.environ.get("DATABASE")
     username = os.environ.get("DATABASE_USERNAME")
     password = os.environ.get("DATABASE_PASSWORD")
     # /opt/microsoft/msodbcsql17/lib64/libmsodbcsql-17.5.so.1.1
     driver_location = os.environ.get("DATABASE_DRIVER_PATH")
+    if (server is None
+        or database is None
+        or username is None
+        or password is None):
+        raise Exception("Missing required arguments")
     cache = {
         "database":database,
         "query":query,
